package org.apache.commons.lang3.builder;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import org.apache.commons.lang3.ArrayUtils;
import org.apache.commons.lang3.Validate;

/* loaded from: org_apache_commons_lang3_builder.jar:org/apache/commons/lang3/builder/DiffBuilder.class */
public class DiffBuilder<T> implements Builder<DiffResult<T>> {
    private final List<Diff<?>> diffs;
    private final boolean objectsTriviallyEqual;
    private final T left;
    private final T right;
    private final ToStringStyle style;

    public DiffBuilder(T lhs, T rhs, ToStringStyle style, boolean testTriviallyEqual) {
        Validate.notNull(lhs, "lhs", new Object[0]);
        Validate.notNull(rhs, "rhs", new Object[0]);
        this.diffs = new ArrayList();
        this.left = lhs;
        this.right = rhs;
        this.style = style;
        this.objectsTriviallyEqual = testTriviallyEqual && (lhs == rhs || lhs.equals(rhs));
    }

    public DiffBuilder(T lhs, T rhs, ToStringStyle style) {
        this(lhs, rhs, style, true);
    }

    public DiffBuilder<T> append(String fieldName, final boolean lhs, final boolean rhs) {
        validateFieldNameNotNull(fieldName);
        if (this.objectsTriviallyEqual) {
            return this;
        }
        if (lhs != rhs) {
            this.diffs.add(new Diff<Boolean>(fieldName) { // from class: org.apache.commons.lang3.builder.DiffBuilder.1
                private static final long serialVersionUID = 1;

                /* renamed from: getLeft, reason: merged with bridge method [inline-methods] */
                public Boolean m1getLeft() {
                    return Boolean.valueOf(lhs);
                }

                /* renamed from: getRight, reason: merged with bridge method [inline-methods] */
                public Boolean m0getRight() {
                    return Boolean.valueOf(rhs);
                }
            });
        }
        return this;
    }

    public DiffBuilder<T> append(String fieldName, final boolean[] lhs, final boolean[] rhs) {
        validateFieldNameNotNull(fieldName);
        if (this.objectsTriviallyEqual) {
            return this;
        }
        if (!Arrays.equals(lhs, rhs)) {
            this.diffs.add(new Diff<Boolean[]>(fieldName) { // from class: org.apache.commons.lang3.builder.DiffBuilder.2
                private static final long serialVersionUID = 1;

                /* renamed from: getLeft, reason: merged with bridge method [inline-methods] */
                public Boolean[] m19getLeft() {
                    return ArrayUtils.toObject(lhs);
                }

                /* renamed from: getRight, reason: merged with bridge method [inline-methods] */
                public Boolean[] m18getRight() {
                    return ArrayUtils.toObject(rhs);
                }
            });
        }
        return this;
    }

    public DiffBuilder<T> append(String fieldName, final byte lhs, final byte rhs) {
        validateFieldNameNotNull(fieldName);
        if (this.objectsTriviallyEqual) {
            return this;
        }
        if (lhs != rhs) {
            this.diffs.add(new Diff<Byte>(fieldName) { // from class: org.apache.commons.lang3.builder.DiffBuilder.3
                private static final long serialVersionUID = 1;

                /* renamed from: getLeft, reason: merged with bridge method [inline-methods] */
                public Byte m21getLeft() {
                    return Byte.valueOf(lhs);
                }

                /* renamed from: getRight, reason: merged with bridge method [inline-methods] */
                public Byte m20getRight() {
                    return Byte.valueOf(rhs);
                }
            });
        }
        return this;
    }

    public DiffBuilder<T> append(String fieldName, final byte[] lhs, final byte[] rhs) {
        validateFieldNameNotNull(fieldName);
        if (this.objectsTriviallyEqual) {
            return this;
        }
        if (!Arrays.equals(lhs, rhs)) {
            this.diffs.add(new Diff<Byte[]>(fieldName) { // from class: org.apache.commons.lang3.builder.DiffBuilder.4
                private static final long serialVersionUID = 1;

                /* renamed from: getLeft, reason: merged with bridge method [inline-methods] */
                public Byte[] m23getLeft() {
                    return ArrayUtils.toObject(lhs);
                }

                /* renamed from: getRight, reason: merged with bridge method [inline-methods] */
                public Byte[] m22getRight() {
                    return ArrayUtils.toObject(rhs);
                }
            });
        }
        return this;
    }

    public DiffBuilder<T> append(String fieldName, final char lhs, final char rhs) {
        validateFieldNameNotNull(fieldName);
        if (this.objectsTriviallyEqual) {
            return this;
        }
        if (lhs != rhs) {
            this.diffs.add(new Diff<Character>(fieldName) { // from class: org.apache.commons.lang3.builder.DiffBuilder.5
                private static final long serialVersionUID = 1;

                /* renamed from: getLeft, reason: merged with bridge method [inline-methods] */
                public Character m25getLeft() {
                    return Character.valueOf(lhs);
                }

                /* renamed from: getRight, reason: merged with bridge method [inline-methods] */
                public Character m24getRight() {
                    return Character.valueOf(rhs);
                }
            });
        }
        return this;
    }

    public DiffBuilder<T> append(String fieldName, final char[] lhs, final char[] rhs) {
        validateFieldNameNotNull(fieldName);
        if (this.objectsTriviallyEqual) {
            return this;
        }
        if (!Arrays.equals(lhs, rhs)) {
            this.diffs.add(new Diff<Character[]>(fieldName) { // from class: org.apache.commons.lang3.builder.DiffBuilder.6
                private static final long serialVersionUID = 1;

                /* renamed from: getLeft, reason: merged with bridge method [inline-methods] */
                public Character[] m27getLeft() {
                    return ArrayUtils.toObject(lhs);
                }

                /* renamed from: getRight, reason: merged with bridge method [inline-methods] */
                public Character[] m26getRight() {
                    return ArrayUtils.toObject(rhs);
                }
            });
        }
        return this;
    }

    public DiffBuilder<T> append(String fieldName, final double lhs, final double rhs) {
        validateFieldNameNotNull(fieldName);
        if (this.objectsTriviallyEqual) {
            return this;
        }
        if (Double.doubleToLongBits(lhs) != Double.doubleToLongBits(rhs)) {
            this.diffs.add(new Diff<Double>(fieldName) { // from class: org.apache.commons.lang3.builder.DiffBuilder.7
                private static final long serialVersionUID = 1;

                /* renamed from: getLeft, reason: merged with bridge method [inline-methods] */
                public Double m29getLeft() {
                    return Double.valueOf(lhs);
                }

                /* renamed from: getRight, reason: merged with bridge method [inline-methods] */
                public Double m28getRight() {
                    return Double.valueOf(rhs);
                }
            });
        }
        return this;
    }

    public DiffBuilder<T> append(String fieldName, final double[] lhs, final double[] rhs) {
        validateFieldNameNotNull(fieldName);
        if (this.objectsTriviallyEqual) {
            return this;
        }
        if (!Arrays.equals(lhs, rhs)) {
            this.diffs.add(new Diff<Double[]>(fieldName) { // from class: org.apache.commons.lang3.builder.DiffBuilder.8
                private static final long serialVersionUID = 1;

                /* renamed from: getLeft, reason: merged with bridge method [inline-methods] */
                public Double[] m31getLeft() {
                    return ArrayUtils.toObject(lhs);
                }

                /* renamed from: getRight, reason: merged with bridge method [inline-methods] */
                public Double[] m30getRight() {
                    return ArrayUtils.toObject(rhs);
                }
            });
        }
        return this;
    }

    public DiffBuilder<T> append(String fieldName, final float lhs, final float rhs) {
        validateFieldNameNotNull(fieldName);
        if (this.objectsTriviallyEqual) {
            return this;
        }
        if (Float.floatToIntBits(lhs) != Float.floatToIntBits(rhs)) {
            this.diffs.add(new Diff<Float>(fieldName) { // from class: org.apache.commons.lang3.builder.DiffBuilder.9
                private static final long serialVersionUID = 1;

                /* renamed from: getLeft, reason: merged with bridge method [inline-methods] */
                public Float m33getLeft() {
                    return Float.valueOf(lhs);
                }

                /* renamed from: getRight, reason: merged with bridge method [inline-methods] */
                public Float m32getRight() {
                    return Float.valueOf(rhs);
                }
            });
        }
        return this;
    }

    public DiffBuilder<T> append(String fieldName, final float[] lhs, final float[] rhs) {
        validateFieldNameNotNull(fieldName);
        if (this.objectsTriviallyEqual) {
            return this;
        }
        if (!Arrays.equals(lhs, rhs)) {
            this.diffs.add(new Diff<Float[]>(fieldName) { // from class: org.apache.commons.lang3.builder.DiffBuilder.10
                private static final long serialVersionUID = 1;

                /* renamed from: getLeft, reason: merged with bridge method [inline-methods] */
                public Float[] m3getLeft() {
                    return ArrayUtils.toObject(lhs);
                }

                /* renamed from: getRight, reason: merged with bridge method [inline-methods] */
                public Float[] m2getRight() {
                    return ArrayUtils.toObject(rhs);
                }
            });
        }
        return this;
    }

    public DiffBuilder<T> append(String fieldName, final int lhs, final int rhs) {
        validateFieldNameNotNull(fieldName);
        if (this.objectsTriviallyEqual) {
            return this;
        }
        if (lhs != rhs) {
            this.diffs.add(new Diff<Integer>(fieldName) { // from class: org.apache.commons.lang3.builder.DiffBuilder.11
                private static final long serialVersionUID = 1;

                /* renamed from: getLeft, reason: merged with bridge method [inline-methods] */
                public Integer m5getLeft() {
                    return Integer.valueOf(lhs);
                }

                /* renamed from: getRight, reason: merged with bridge method [inline-methods] */
                public Integer m4getRight() {
                    return Integer.valueOf(rhs);
                }
            });
        }
        return this;
    }

    public DiffBuilder<T> append(String fieldName, final int[] lhs, final int[] rhs) {
        validateFieldNameNotNull(fieldName);
        if (this.objectsTriviallyEqual) {
            return this;
        }
        if (!Arrays.equals(lhs, rhs)) {
            this.diffs.add(new Diff<Integer[]>(fieldName) { // from class: org.apache.commons.lang3.builder.DiffBuilder.12
                private static final long serialVersionUID = 1;

                /* renamed from: getLeft, reason: merged with bridge method [inline-methods] */
                public Integer[] m7getLeft() {
                    return ArrayUtils.toObject(lhs);
                }

                /* renamed from: getRight, reason: merged with bridge method [inline-methods] */
                public Integer[] m6getRight() {
                    return ArrayUtils.toObject(rhs);
                }
            });
        }
        return this;
    }

    public DiffBuilder<T> append(String fieldName, final long lhs, final long rhs) {
        validateFieldNameNotNull(fieldName);
        if (this.objectsTriviallyEqual) {
            return this;
        }
        if (lhs != rhs) {
            this.diffs.add(new Diff<Long>(fieldName) { // from class: org.apache.commons.lang3.builder.DiffBuilder.13
                private static final long serialVersionUID = 1;

                /* renamed from: getLeft, reason: merged with bridge method [inline-methods] */
                public Long m9getLeft() {
                    return Long.valueOf(lhs);
                }

                /* renamed from: getRight, reason: merged with bridge method [inline-methods] */
                public Long m8getRight() {
                    return Long.valueOf(rhs);
                }
            });
        }
        return this;
    }

    public DiffBuilder<T> append(String fieldName, final long[] lhs, final long[] rhs) {
        validateFieldNameNotNull(fieldName);
        if (this.objectsTriviallyEqual) {
            return this;
        }
        if (!Arrays.equals(lhs, rhs)) {
            this.diffs.add(new Diff<Long[]>(fieldName) { // from class: org.apache.commons.lang3.builder.DiffBuilder.14
                private static final long serialVersionUID = 1;

                /* renamed from: getLeft, reason: merged with bridge method [inline-methods] */
                public Long[] m11getLeft() {
                    return ArrayUtils.toObject(lhs);
                }

                /* renamed from: getRight, reason: merged with bridge method [inline-methods] */
                public Long[] m10getRight() {
                    return ArrayUtils.toObject(rhs);
                }
            });
        }
        return this;
    }

    public DiffBuilder<T> append(String fieldName, final short lhs, final short rhs) {
        validateFieldNameNotNull(fieldName);
        if (this.objectsTriviallyEqual) {
            return this;
        }
        if (lhs != rhs) {
            this.diffs.add(new Diff<Short>(fieldName) { // from class: org.apache.commons.lang3.builder.DiffBuilder.15
                private static final long serialVersionUID = 1;

                /* renamed from: getLeft, reason: merged with bridge method [inline-methods] */
                public Short m13getLeft() {
                    return Short.valueOf(lhs);
                }

                /* renamed from: getRight, reason: merged with bridge method [inline-methods] */
                public Short m12getRight() {
                    return Short.valueOf(rhs);
                }
            });
        }
        return this;
    }

    public DiffBuilder<T> append(String fieldName, final short[] lhs, final short[] rhs) {
        validateFieldNameNotNull(fieldName);
        if (this.objectsTriviallyEqual) {
            return this;
        }
        if (!Arrays.equals(lhs, rhs)) {
            this.diffs.add(new Diff<Short[]>(fieldName) { // from class: org.apache.commons.lang3.builder.DiffBuilder.16
                private static final long serialVersionUID = 1;

                /* renamed from: getLeft, reason: merged with bridge method [inline-methods] */
                public Short[] m15getLeft() {
                    return ArrayUtils.toObject(lhs);
                }

                /* renamed from: getRight, reason: merged with bridge method [inline-methods] */
                public Short[] m14getRight() {
                    return ArrayUtils.toObject(rhs);
                }
            });
        }
        return this;
    }

    public DiffBuilder<T> append(String fieldName, final Object lhs, final Object rhs) {
        Object objectToTest;
        validateFieldNameNotNull(fieldName);
        if (this.objectsTriviallyEqual) {
            return this;
        }
        if (lhs == rhs) {
            return this;
        }
        if (lhs != null) {
            objectToTest = lhs;
        } else {
            objectToTest = rhs;
        }
        if (objectToTest.getClass().isArray()) {
            if (objectToTest instanceof boolean[]) {
                return append(fieldName, (boolean[]) lhs, (boolean[]) rhs);
            }
            if (objectToTest instanceof byte[]) {
                return append(fieldName, (byte[]) lhs, (byte[]) rhs);
            }
            if (objectToTest instanceof char[]) {
                return append(fieldName, (char[]) lhs, (char[]) rhs);
            }
            if (objectToTest instanceof double[]) {
                return append(fieldName, (double[]) lhs, (double[]) rhs);
            }
            if (objectToTest instanceof float[]) {
                return append(fieldName, (float[]) lhs, (float[]) rhs);
            }
            if (objectToTest instanceof int[]) {
                return append(fieldName, (int[]) lhs, (int[]) rhs);
            }
            if (objectToTest instanceof long[]) {
                return append(fieldName, (long[]) lhs, (long[]) rhs);
            }
            if (objectToTest instanceof short[]) {
                return append(fieldName, (short[]) lhs, (short[]) rhs);
            }
            return append(fieldName, (Object[]) lhs, (Object[]) rhs);
        }
        if (lhs != null && lhs.equals(rhs)) {
            return this;
        }
        this.diffs.add(new Diff<Object>(fieldName) { // from class: org.apache.commons.lang3.builder.DiffBuilder.17
            private static final long serialVersionUID = 1;

            public Object getLeft() {
                return lhs;
            }

            public Object getRight() {
                return rhs;
            }
        });
        return this;
    }

    public DiffBuilder<T> append(String fieldName, final Object[] lhs, final Object[] rhs) {
        validateFieldNameNotNull(fieldName);
        if (this.objectsTriviallyEqual) {
            return this;
        }
        if (!Arrays.equals(lhs, rhs)) {
            this.diffs.add(new Diff<Object[]>(fieldName) { // from class: org.apache.commons.lang3.builder.DiffBuilder.18
                private static final long serialVersionUID = 1;

                /* renamed from: getLeft, reason: merged with bridge method [inline-methods] */
                public Object[] m17getLeft() {
                    return lhs;
                }

                /* renamed from: getRight, reason: merged with bridge method [inline-methods] */
                public Object[] m16getRight() {
                    return rhs;
                }
            });
        }
        return this;
    }

    public DiffBuilder<T> append(String fieldName, DiffResult<T> diffResult) {
        validateFieldNameNotNull(fieldName);
        Validate.notNull(diffResult, "diffResult", new Object[0]);
        if (this.objectsTriviallyEqual) {
            return this;
        }
        for (Diff<?> diff : diffResult.getDiffs()) {
            append(fieldName + "." + diff.getFieldName(), diff.getLeft(), diff.getRight());
        }
        return this;
    }

    @Override // org.apache.commons.lang3.builder.Builder
    public DiffResult<T> build() {
        return new DiffResult<>(this.left, this.right, this.diffs, this.style);
    }

    private void validateFieldNameNotNull(String fieldName) {
        Validate.notNull(fieldName, "fieldName", new Object[0]);
    }
}
